@@ -1,4 +1,4 @@
-from sqlalchemy import Column, BigInteger, Text, DateTime, func
+from sqlalchemy import Column, BigInteger, Text, DateTime
 
 from assimilator.core.events import Event
 from assimilator.core.database.unit_of_work import UnitOfWork
@@ -8,20 +8,25 @@ from assimilator.core.events.events_bus import EventBus
 
 def create_outbox_event_model(Base):
     class OutboxEvent(Base):
-        id = Column(BigInteger())
+        id = Column(BigInteger(), primary_key=True)
         event_data = Column(Text())
-        event_date = Column(DateTime(timezone=True), server_default=func.now())
+        event_date = Column(DateTime(timezone=True))
 
         def __init__(self, event: Event, *args, **kwargs):
-            super(OutboxEvent, self).__init__(event_data=event.json(), *args, **kwargs)
+            super(OutboxEvent, self).__init__(
+                event_data=event.json(),
+                event_date=event.event_date,
+                *args,
+                **kwargs,
+            )
 
     return OutboxEvent
 
 
 class AlchemyOutboxRelay(OutboxRelay):
     def __init__(self, outbox_event_model, uow: UnitOfWork, event_bus: EventBus):
-        self.outbox_event_model = outbox_event_model
         super(AlchemyOutboxRelay, self).__init__(uow=uow, event_bus=event_bus)
+        self.outbox_event_model = outbox_event_model
 
     def start(self):
         while True:
@@ -29,7 +34,7 @@ class AlchemyOutboxRelay(OutboxRelay):
                 events = self.uow.repository.filter()
 
                 for event in events:
-                    self.event_bus.emit(event)
+                    self.event_bus.produce(event)
 
                 self.acknowledge(events)
                 self.uow.commit()
@@ -37,8 +42,14 @@ class AlchemyOutboxRelay(OutboxRelay):
             self.delay_function()
 
     def delay_function(self):
-        raise NotImplementedError("delay function is not implemented")
+        raise NotImplementedError("delay_function() is not implemented")
 
     def acknowledge(self, events):
         for event in events:
             self.uow.repository.delete(event)
+
+
+__all__ = [
+    'create_outbox_event_model',
+    'AlchemyOutboxRelay',
+]
