@@ -1,3 +1,3 @@
 from assimilator.core.database.repository import *
-from assimilator.core.database.specification import *
+from assimilator.core.database.specifications import *
 from assimilator.core.database.unit_of_work import *
