@@ -1,13 +1,13 @@
 from abc import ABC, abstractmethod
 
 
-class ContextManagedConnection(ABC):
+class StartCloseContextMixin(ABC):
     @abstractmethod
-    def close(self):
+    def close(self) -> None:
         raise NotImplementedError("close() is not implemented")
 
     @abstractmethod
-    def start(self):
+    def start(self) -> None:
         raise NotImplementedError("start() is not implemented")
 
     def __enter__(self):
@@ -19,3 +19,8 @@ class ContextManagedConnection(ABC):
 
         if exc_type is not None:
             raise exc_val
+
+
+__all__ = [
+    'StartCloseContextMixin',
+]
